@@ -16,7 +16,7 @@ use rattler_conda_types::{
 
 use crate::interface::Interface;
 use crate::workspace::add::GitOptions;
-use crate::workspace::{ChannelOptions, DependencyOptions, InitOptions, ReinstallOptions};
+use crate::workspace::{ChannelOptions, DependencyOptions, InitOptions, Package, ReinstallOptions};
 
 pub struct DefaultContext<I: Interface> {
     _interface: I,
@@ -204,6 +204,27 @@ impl<I: Interface> WorkspaceContext<I> {
         .await
     }
 
+    pub async fn list_packages(
+        &self,
+        regex: Option<String>,
+        platform: Option<Platform>,
+        environment: Option<String>,
+        explicit: bool,
+        no_install: bool,
+        lock_file_usage: LockFileUsage,
+    ) -> miette::Result<Vec<Package>> {
+        crate::workspace::list::list(
+            &self.workspace,
+            regex,
+            platform,
+            environment,
+            explicit,
+            no_install,
+            lock_file_usage,
+        )
+        .await
+    }
+
     pub async fn list_features(&self) -> IndexMap<FeatureName, Feature> {
         crate::workspace::workspace::feature::list_features(&self.workspace).await
     }
