@@ -8,6 +8,9 @@ pub(crate) mod remove;
 pub(crate) mod init;
 pub use init::{GitAttributes, InitOptions, ManifestFormat};
 
+pub(crate) mod list;
+pub use list::{Package, PackageKind};
+
 pub(crate) mod reinstall;
 pub use reinstall::ReinstallOptions;
 
