@@ -5,7 +5,7 @@ use std::path::PathBuf;
 use ordermap::OrderMap;
 use serde::{Deserialize, Serialize};
 
-use crate::{TargetSelectorV1, VersionedProjectModel};
+use crate::{ProjectModel, TargetSelector};
 
 pub const METHOD_NAME: &str = "initialize";
 
@@ -35,12 +35,12 @@ pub struct InitializeParams {
     /// `manifest_path` as the source directory.
     ///
     /// This is an absolute path. This is always a directory.
-    pub source_dir: Option<PathBuf>,
+    pub source_directory: Option<PathBuf>,
 
     /// The root directory of the workspace.
     ///
     /// This is an absolute path.
-    pub workspace_root: Option<PathBuf>,
+    pub workspace_directory: Option<PathBuf>,
 
     /// Optionally the cache directory to use for any caching activity.
     pub cache_directory: Option<PathBuf>,
@@ -48,13 +48,13 @@ pub struct InitializeParams {
     /// Project model that the backend should use even though it is an option
     /// it is highly recommended to use this field. Otherwise, it will be very
     /// easy to break backwards compatibility.
-    pub project_model: Option<VersionedProjectModel>,
+    pub project_model: Option<ProjectModel>,
 
     /// Backend specific configuration passed from the frontend to the backend.
     pub configuration: Option<serde_json::Value>,
 
     /// Targets that apply to the backend.
-    pub target_configuration: Option<OrderMap<TargetSelectorV1, serde_json::Value>>,
+    pub target_configuration: Option<OrderMap<TargetSelector, serde_json::Value>>,
 }
 
 /// The result of the initialize request.
