@@ -26,7 +26,7 @@ use pixi_manifest::{FeaturesExt, TaskName};
 use pixi_progress::global_multi_progress;
 use pixi_task::{
     AmbiguousTask, CanSkip, ExecutableTask, FailedToParseShellScript, InvalidWorkingDirectory,
-    SearchEnvironments, TaskAndEnvironment, TaskGraph, get_task_env,
+    PreferExecutable, SearchEnvironments, TaskAndEnvironment, TaskGraph, get_task_env,
 };
 use rattler_conda_types::Platform;
 use thiserror::Error;
@@ -50,6 +50,12 @@ pub struct Args {
     /// environment, which can be an executable in the environment's PATH.
     pub task: Vec<String>,
 
+    /// Execute the command as an executable without resolving Pixi tasks.
+    ///
+    /// Useful when a task name and an executable have the same name.
+    #[arg(long = "executable", short = 'x')]
+    pub executable: bool,
+
     #[clap(flatten)]
     pub workspace_config: WorkspaceConfig,
 
@@ -78,6 +84,14 @@ pub struct Args {
     #[arg(long)]
     pub skip_deps: bool,
 
+    /// Enable template rendering for the command arguments.
+    ///
+    /// By default, arguments passed to `pixi run` on the command line are not
+    /// processed by the template engine. Use this flag to enable rendering
+    /// of template variables like `{{ pixi.platform }}`.
+    #[arg(long)]
+    pub templated: bool,
+
     /// Run the task in dry-run mode (only print the command that would run)
     #[clap(short = 'n', long)]
     pub dry_run: bool,
@@ -178,9 +192,18 @@ pub async fn execute(args: Args) -> miette::Result<()> {
         SearchEnvironments::from_opt_env(&workspace, explicit_environment.clone(), search_platform)
             .with_disambiguate_fn(disambiguate_task_interactive);
 
-    let task_graph =
-        TaskGraph::from_cmd_args(&workspace, &search_environment, args.task, args.skip_deps)?;
-
+    let task_graph = TaskGraph::from_cmd_args(
+        &workspace,
+        &search_environment,
+        args.task,
+        args.skip_deps,
+        if args.executable {
+            PreferExecutable::Always
+        } else {
+            PreferExecutable::TaskFirst
+        },
+        args.templated,
+    )?;
     tracing::debug!("Task graph: {}", task_graph);
 
     // Print dry-run message if dry-run mode is enabled
@@ -202,8 +225,10 @@ pub async fn execute(args: Args) -> miette::Result<()> {
     // make sure that child processes are killed when pixi stops
     let _drop_guard = signal.clone().drop_guard();
 
+    let init_cwd = std::env::current_dir().ok();
     for task_id in task_graph.topological_order() {
-        let executable_task = ExecutableTask::from_task_graph(&task_graph, task_id);
+        let executable_task =
+            ExecutableTask::from_task_graph(&task_graph, task_id, init_cwd.clone());
 
         // If the task is not executable (e.g. an alias), we skip it. This ensures we
         // don't instantiate a prefix for an alias.
