@@ -414,6 +414,18 @@ pub struct TaskArg {
 
     /// The default value of the argument
     pub default: Option<String>,
+
+    /// The allowed values for the argument
+    pub choices: Option<Vec<String>>,
+}
+
+impl TaskArg {
+    /// Returns whether `value` is allowed by this argument's choices (if any).
+    pub fn is_valid_value(&self, value: &str) -> bool {
+        self.choices
+            .as_ref()
+            .is_none_or(|choices| choices.iter().any(|c| c == value))
+    }
 }
 
 impl std::str::FromStr for TaskArg {
@@ -423,6 +435,7 @@ impl std::str::FromStr for TaskArg {
         Ok(TaskArg {
             name: ArgName::from_str(s)?,
             default: None,
+            choices: None,
         })
     }
 }
@@ -871,10 +884,18 @@ impl From<Task> for Item {
                 if let Some(args) = &process.args {
                     let mut args_array = Array::new();
                     for arg in args {
-                        if let Some(default) = &arg.default {
+                        if arg.default.is_some() || arg.choices.is_some() {
                             let mut arg_table = Table::new().into_inline_table();
                             arg_table.insert("arg", arg.name.as_str().into());
-                            arg_table.insert("default", default.into());
+                            if let Some(default) = &arg.default {
+                                arg_table.insert("default", default.into());
+                            }
+                            if let Some(choices) = &arg.choices {
+                                arg_table.insert(
+                                    "choices",
+                                    Value::Array(Array::from_iter(choices.iter())),
+                                );
+                            }
                             args_array.push(Value::InlineTable(arg_table));
                         } else {
                             args_array.push(Value::String(toml_edit::Formatted::new(
@@ -943,10 +964,18 @@ impl From<Task> for Item {
                     if let Some(args_vec) = &alias.args {
                         let mut args = Vec::new();
                         for arg in args_vec {
-                            if let Some(default) = &arg.default {
+                            if arg.default.is_some() || arg.choices.is_some() {
                                 let mut arg_table = Table::new().into_inline_table();
                                 arg_table.insert("arg", arg.name.as_str().into());
-                                arg_table.insert("default", default.into());
+                                if let Some(default) = &arg.default {
+                                    arg_table.insert("default", default.into());
+                                }
+                                if let Some(choices) = &arg.choices {
+                                    arg_table.insert(
+                                        "choices",
+                                        Value::Array(Array::from_iter(choices.iter())),
+                                    );
+                                }
                                 args.push(Value::InlineTable(arg_table));
                             } else {
                                 args.push(Value::String(toml_edit::Formatted::new(
