@@ -1,7 +1,9 @@
+mod canonical_spec;
 mod dev_source_record;
 mod pinned_source;
 mod source_record;
 
+pub use canonical_spec::{CanonicalGit, CanonicalPath, CanonicalSourceLocation, CanonicalUrl};
 pub use dev_source_record::DevSourceRecord;
 
 use std::path::Path;
