@@ -1,5 +1,5 @@
 use crate::{GitSpec, PathSourceSpec, SourceLocationSpec, SourceSpec, Subdirectory, UrlSourceSpec};
-use pixi_consts::consts::{KNOWN_MANIFEST_FILES, RATTLER_BUILD_FILE_NAMES, ROS_BACKEND_FILE_NAMES};
+use pixi_consts::consts::KNOWN_MANIFEST_FILES;
 use pixi_path::normalize;
 use typed_path::Utf8TypedPath;
 
@@ -114,10 +114,6 @@ impl SourceAnchor {
 /// to the workspace root.
 fn is_known_manifest_file(path: Utf8TypedPath<'_>) -> bool {
     path.file_name()
-        .map(|name| {
-            KNOWN_MANIFEST_FILES.contains(&name)
-                || RATTLER_BUILD_FILE_NAMES.contains(&name)
-                || ROS_BACKEND_FILE_NAMES.contains(&name)
-        })
+        .map(|name| KNOWN_MANIFEST_FILES.contains(&name))
         .unwrap_or(false)
 }
